==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/or.php <==
<?php

return [
    'Names' => [
        'Arab' => 'ଆରବିକ୍',
        'Armi' => 'ଇମ୍ପେରିଆଲ୍ ଆରମିକ୍',
        'Armn' => 'ଆର୍ମେନୀୟ',
        'Avst' => 'ଆବେସ୍ଥାନ୍',
        'Bali' => 'ବାଲିନୀଜ୍',
        'Batk' => 'ବାଟାକ୍',
        'Beng' => 'ବଙ୍ଗାଳୀ',
        'Blis' => 'ବ୍ଲିସିମ୍ବଲସ୍',
        'Bopo' => 'ବୋପୋମୋଫୋ',
        'Brah' => 'ବ୍ରାହ୍ମୀ',
        'Brai' => 'ବ୍ରେଲ୍',
        'Bugi' => 'ବୁଗାନୀଜ୍',
        'Buhd' => 'ବୁହିଦ୍',
        'Cakm' => 'ଚକମା',
        'Cans' => 'ୟୁନିଫାଏଡ୍ କାନାଡିଆନ୍ ଆବ୍ରୋଜିନାଲ୍ ସିଲାବିକସ୍',
        'Cari' => 'କୈରନ୍',
        'Cham' => 'ଛମ୍',
        'Cher' => 'ଚିରୁକୀ',
        'Cirt' => 'ସିର୍ଥ',
        'Copt' => 'କପଟିକ୍',
        'Cprt' => 'ସିପ୍ରଅଟ୍',
        'Cyrl' => 'ସିରିଲିକ୍',
        'Cyrs' => 'ଓଲ୍ଡ ଚର୍ଚ୍ଚ ସାଲଭୋନିକ୍ ସିରିଲିକ୍',
        'Deva' => 'ଦେବନଗରୀ',
        'Dsrt' => 'ଡେସର୍ଟ',
        'Egyd' => 'ଇଜିପ୍ଟିଆନ୍ ଡେମୋଟିକ୍',
        'Egyh' => 'ଇଜିପ୍ଟିଆନ୍ ହାଇଅରଟିକ୍',
        'Egyp' => 'ଇଜିପ୍ଟିଆନ୍ ହାଅରଗ୍ଲିପସ୍',
        'Ethi' => 'ଇଥିଓପିକ୍‌',
        'Geok' => 'ଜର୍ଜିଆନ୍ ଖୁଟସୁରୀ',
        'Geor' => 'ଜର୍ଜିୟ',
        'Glag' => 'ଗ୍ଲାଗ୍ଲୋଟିକ୍',
        'Goth' => 'ଗୋଥିକ୍',
        'Grek' => 'ଗ୍ରୀକ୍',
        'Gujr' => 'ଗୁଜୁରାଟୀ',
        'Guru' => 'ଗୁରମୁଖୀ',
        'Hanb' => 'ବୋପୋମୋଫୋ ସହିତ ହାନ୍‌',
        'Hang' => 'ହାଙ୍ଗୁଲ୍',
        'Hani' => 'ହାନ୍',
        'Hano' => 'ହାନୁନ୍',
        'Hans' => 'ସରଳୀକୃତ',
        'Hant' => 'ପାରମ୍ପରିକ',
        'Hebr' => 'ହିବୃ',
        'Hira' => 'ହିରାଗାନା',
        'Hmng' => 'ପାହୋ ହୋଙ୍ଗ',
        'Hrkt' => 'ଜାପାନୀ ସିଲାବରିଜ୍‌',
        'Hung' => 'ପୁରୁଣା ହଙ୍ଗେରିଆନ୍',
        'Inds' => 'ସିନ୍ଧୁ',
        'Ital' => 'ପୁରୁଣା ଇଟାଲୀ',
        'Jamo' => 'ଜାମୋ',
        'Java' => 'ଜାଭାନୀଜ୍',
        'Jpan' => 'ଜାପାନୀଜ୍',
        'Kali' => 'କାୟାହା ଲୀ',
        'Kana' => 'କାତାକାନା',
        'Khar' => 'ଖାରୋସ୍ଥି',
        'Khmr' => 'ଖମେର୍',
        'Knda' => 'କନ୍ନଡ଼',
        'Kore' => 'କୋରିଆନ୍',
        'Kthi' => 'କୈଥି',
        'Lana' => 'ଲାନା',
        'Laoo' => 'ଲାଓ',
        'Latf' => 'ଫ୍ରାକଥୁର୍ ଲାଟିନ୍',
        'Latg' => 'ଗାଏଲିକ୍ ଲାଟିନ୍',
        'Latn' => 'ଲାଟିନ୍',
        'Lepc' => 'ଲେପଚା',
        'Limb' => 'ଲିମ୍ବୁ',
        'Lina' => 'ଲିନିୟର୍',
        'Linb' => 'ଲିନିୟର୍ ବି',
        'Lyci' => 'ଲିଶିୟନ୍',
        'Lydi' => 'ଲିଡିୟନ୍',
        'Mand' => 'ମାନଡେନ୍',
        'Mani' => 'ମନଶୀନ୍',
        'Maya' => 'ମୟାନ୍ ହାୟରଲଜିକସ୍',
        'Mero' => 'ମେରୋଇଟିକ୍',
        'Mlym' => 'ମାଲାୟଲମ୍',
        'Mong' => 'ମଙ୍ଗୋଲିଆନ୍',
        'Moon' => 'ଚନ୍ଦ୍ର',
        'Mtei' => 'ମାଏତି ମାୟେକ୍',
        'Mymr' => 'ମ୍ୟାନମାର୍',
        'Nkoo' => 'ଏନ୍ କୋ',
        'Ogam' => 'ଓଘାମା',
        'Olck' => 'ଓଲ୍ ଚିକି',
        'Orkh' => 'ଓରୋଖନ୍',
        'Orya' => 'ଓଡ଼ିଆ',
        'Osma' => 'ଓସୋମାନିୟା',
        'Perm' => 'ଓଲ୍ଡ ପରମିକ୍',
        'Phag' => 'ଫାଗସ୍-ପା',
        'Phli' => 'ଇନସ୍କ୍ରୀପସାନଲ୍ ପାହାଲାୱୀ',
        'Phlp' => 'ସ୍ଲାଟର୍ ପାହାଲାୱୀ',
        'Phlv' => 'ବୁକ୍ ପାହାଲାୱୀ',
        'Phnx' => 'ଫେନୋସିଆନ୍',
        'Plrd' => 'ପୋଲାର୍ଡ ଫୋନେଟିକ୍',
        'Prti' => 'ଇନସ୍କ୍ରୀପସାନଲ୍ ପାର୍ଥିଆନ୍',
        'Rjng' => 'ରେଜାଙ୍ଗ',
        'Roro' => 'ରୋଙ୍ଗୋରୋଙ୍ଗୋ',
        'Runr' => 'ରନିକ୍',
        'Samr' => 'ସମୌରିଟନ୍',
        'Sara' => 'ସାରାତି',
        'Saur' => 'ସୌରାଷ୍ଟ୍ର',
        'Sgnw' => 'ସାଙ୍କେତିକ ଲିଖ',
        'Shaw' => 'ସାବିୟାନ୍',
        'Sinh' => 'ସିଂହଳ',
        'Sund' => 'ସୁଦାନୀଜ୍',
        'Sylo' => 'ସୀଲିତୋ ନଗରୀ',
        'Syrc' => 'ସିରିୟାକ୍',
        'Syre' => 'ଏଷ୍ଟ୍ରାଙ୍ଗେଲୋ ସିରିକ୍',
        'Syrj' => 'ୱେଷ୍ଟର୍ନ ସିରିକ୍',
        'Syrn' => 'ଇଷ୍ଟର୍ନ ସିରିକ୍',
        'Tagb' => 'ତଗବାନ୍ୱା',
        'Tale' => 'ତାଇ ଲେ',
        'Talu' => 'ନୂତନ ତାଇ ଲୁଏ',
        'Taml' => 'ତାମିଲ୍',
        'Tavt' => 'ତାଇ ଭିଏତ୍',
        'Telu' => 'ତେଲୁଗୁ',
        'Teng' => 'ତେଙ୍ଗୱାର୍',
        'Tfng' => 'ତିଫିଙ୍ଘା',
        'Tglg' => 'ଟାଗାଲୋଗ୍',
        'Thaa' => 'ଥାନା',
        'Thai' => 'ଥାଇ',
        'Tibt' => 'ତିବେତାନ୍',
        'Ugar' => 'ୟୁଗାରିଟିକ୍',
        'Vaii' => 'ୱାଇ',
        'Visp' => 'ଭିଜିବଲ୍ ସ୍ପିଚ୍',
        'Xpeo' => 'ପୁରୁଣା ଫରାସୀ',
        'Xsux' => 'ସୁମେରୋ-ଆକ୍କାଡିଆନ୍ ସୁନିଫର୍ମ',
        'Yiii' => 'ୟୀ',
        'Zinh' => 'ବଂଶଗତ',
        'Zmth' => 'ଗାଣିତିକ ନୋଟେସନ୍',
        'Zsye' => 'ଇମୋଜି',
        'Zsym' => 'ସଙ୍କେତଗୁଡ଼ିକ',
        'Zxxx' => 'ଅଲିଖିତ',
        'Zyyy' => 'ସାଧାରଣ',
    ],
];

==> symfony_6.4.21+dfsg.orig.tar.xz: symfony-6.4.21/src/Symfony/Component/Intl/Resources/data/scripts/or.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'ଆଡଲମ୍',
        'Arab' => 'ଆରବିକ୍',
        'Aran' => 'ନାଷ୍ଟାଲିକ୍‌',
        'Armi' => 'ଇମ୍ପେରିଆଲ୍ ଆରମିକ୍',
        'Armn' => 'ଆର୍ମେନୀୟ',
        'Avst' => 'ଆବେସ୍ଥାନ୍',
        'Bali' => 'ବାଲିନୀଜ୍',
        'Batk' => 'ବାଟାକ୍',
        'Beng' => 'ବଙ୍ଗାଳୀ',
        'Blis' => 'ବ୍ଲିସିମ୍ବଲସ୍',
        'Bopo' => 'ବୋପୋମୋଫୋ',
        'Brah' => 'ବ୍ରାହ୍ମୀ',
        'Brai' => 'ବ୍ରେଲ୍',
        'Bugi' => 'ବୁଗାନୀଜ୍',
        'Buhd' => 'ବୁହିଦ୍',
        'Cakm' => 'ଚକମା',
        'Cans' => 'ୟୁନିଫାଏଡ୍ କାନାଡିଆନ୍ ଆବ୍ରୋଜିନାଲ୍ ସିଲାବିକସ୍',
        'Cari' => 'କୈରନ୍',
        'Cham' => 'ଛମ୍',
        'Cher' => 'ଚିରୁକୀ',
        'Cirt' => 'ସିର୍ଥ',
        'Copt' => 'କପଟିକ୍',
        'Cprt' => 'ସିପ୍ରଅଟ୍',
        'Cyrl' => 'ସିରିଲିକ୍',
        'Cyrs' => 'ଓଲ୍ଡ ଚର୍ଚ୍ଚ ସାଲଭୋନିକ୍ ସିରିଲିକ୍',
        'Deva' => 'ଦେବନାଗରୀ',
        'Dsrt' => 'ଡେସର୍ଟ',
        'Egyd' => 'ଇଜିପ୍ଟିଆନ୍ ଡେମୋଟିକ୍',
        'Egyh' => 'ଇଜିପ୍ଟିଆନ୍ ହାଇଅରଟିକ୍',
        'Egyp' => 'ଇଜିପ୍ଟିଆନ୍ ହାଅରଗ୍ଲିପସ୍',
        'Ethi' => 'ଇଥିଓପିକ୍‌',
        'Geok' => 'ଜର୍ଜିଆନ୍ ଖୁଟସୁରୀ',
        'Geor' => 'ଜର୍ଜିୟ',
        'Glag' => 'ଗ୍ଲାଗ୍ଲୋଟିକ୍',
        'Goth' => 'ଗୋଥିକ୍',
        'Grek' => 'ଗ୍ରୀକ୍',
        'Gujr' => 'ଗୁଜରାଟୀ',
        'Guru' => 'ଗୁରମୁଖୀ',
        'Hanb' => 'ବୋପୋମୋଫୋ ସହିତ ହାନ୍‌',
        'Hang' => 'ହାଙ୍ଗୁଲ୍',
        'Hani' => 'ହାନ୍',
        'Hano' => 'ହାନୁନ୍',
        'Hans' => 'ସରଳୀକୃତ',
        'Hant' => 'ପାରମ୍ପରିକ',
        'Hebr' => 'ହିବୃ',
        'Hira' => 'ହିରାଗାନା',
        'Hmng' => 'ପାହୋ ହୋଙ୍ଗ',
        'Hrkt' => 'ଜାପାନୀ ସିଲାବରିଜ୍‌',
        'Hung' => 'ପୁରୁଣା ହଙ୍ଗେରିଆନ୍',
        'Inds' => 'ସିନ୍ଧୁ',
        'Ital' => 'ପୁରୁଣା ଇଟାଲୀ',
        'Jamo' => 'ଜାମୋ',
        'Java' => 'ଜାଭାନୀଜ୍',
        'Jpan' => 'ଜାପାନୀଜ୍',
        'Kali' => 'କାୟାହା ଲୀ',
        'Kana' => 'କାତାକାନା',
        'Khar' => 'ଖାରୋସ୍ଥି',
        'Khmr' => 'ଖମେର୍',
        'Knda' => 'କନ୍ନଡ଼',
        'Kore' => 'କୋରିଆନ୍',
        'Kthi' => 'କୈଥି',
        'Lana' => 'ଲାନା',
        'Laoo' => 'ଲାଓ',
        'Latf' => 'ଫ୍ରାକଥୁର୍ ଲାଟିନ୍',
        'Latg' => 'ଗାଏଲିକ୍ ଲାଟିନ୍',
        'Latn' => 'ଲାଟିନ୍',
        'Lepc' => 'ଲେପଚା',
        'Limb' => 'ଲିମ୍ବୁ',
        'Lina' => 'ଲିନିୟର୍',
        'Linb' => 'ଲିନିୟର୍ ବି',
        'Lyci' => 'ଲିଶିୟନ୍',
        'Lydi' => 'ଲିଡିୟନ୍',
        'Mand' => 'ମାନଡେନ୍',
        'Mani' => 'ମନଶୀନ୍',
        'Maya' => 'ମୟାନ୍ ହାୟରଲଜିକସ୍',
        'Mero' => 'ମେରୋଇଟିକ୍',
        'Mlym' => 'ମାଲାୟାଲମ୍',
        'Mong' => 'ମଙ୍ଗୋଲିଆନ୍',
        'Moon' => 'ଚନ୍ଦ୍ର',
        'Mtei' => 'ମାଏତି ମାୟେକ୍',
        'Mymr' => 'ମ୍ୟାନମାର୍',
        'Nkoo' => 'ଏନ୍ କୋ',
        'Ogam' => 'ଓଘାମା',
        'Olck' => 'ଅଲ୍ ଚିକି',
        'Orkh' => 'ଓରୋଖନ୍',
        'Orya' => 'ଓଡ଼ିଆ',
        'Osma' => 'ଓସୋମାନିୟା',
        'Perm' => 'ଓଲ୍ଡ ପରମିକ୍',
        'Phag' => 'ଫାଗସ୍-ପା',
        'Phli' => 'ଇନସ୍କ୍ରୀପସାନଲ୍ ପାହାଲାୱୀ',
        'Phlp' => 'ସ୍ଲାଟର୍ ପାହାଲାୱୀ',
        'Phlv' => 'ବୁକ୍ ପାହାଲାୱୀ',
        'Phnx' => 'ଫେନୋସିଆନ୍',
        'Plrd' => 'ପୋଲାର୍ଡ ଫୋନେଟିକ୍',
        'Prti' => 'ଇନସ୍କ୍ରୀପସାନଲ୍ ପାର୍ଥିଆନ୍',
        'Rjng' => 'ରେଜାଙ୍ଗ',
        'Rohg' => 'ହାନିଫି',
        'Roro' => 'ରୋଙ୍ଗୋରୋଙ୍ଗୋ',
        'Runr' => 'ରନିକ୍',
        'Samr' => 'ସମୌରିଟନ୍',
        'Sara' => 'ସାରାତି',
        'Saur' => 'ସୌରାଷ୍ଟ୍ର',
        'Sgnw' => 'ସାଙ୍କେତିକ ଲିଖ',
        'Shaw' => 'ସାବିୟାନ୍',
        'Sinh' => 'ସିଂହଳ',
        'Sund' => 'ସୁଦାନିଜ୍',
        'Sylo' => 'ସୀଲିତୋ ନଗରୀ',
        'Syrc' => 'ସିରିୟାକ୍',
        'Syre' => 'ଏଷ୍ଟ୍ରାଙ୍ଗେଲୋ ସିରିକ୍',
        'Syrj' => 'ୱେଷ୍ଟର୍ନ ସିରିକ୍',
        'Syrn' => 'ଇଷ୍ଟର୍ନ ସିରିକ୍',
        'Tagb' => 'ତଗବାନ୍ୱା',
        'Tale' => 'ତାଇ ଲେ',
        'Talu' => 'ନୂତନ ତାଇ ଲୁଏ',
        'Taml' => 'ତାମିଲ୍',
        'Tavt' => 'ତାଇ ଭିଏତ୍',
        'Telu' => 'ତେଲୁଗୁ',
        'Teng' => 'ତେଙ୍ଗୱାର୍',
        'Tfng' => 'ଟିଫିନାଘ୍‌',
        'Tglg' => 'ଟାଗାଲୋଗ୍',
        'Thaa' => 'ଥାନା',
        'Thai' => 'ଥାଇ',
        'Tibt' => 'ତିବେତାନ୍',
        'Ugar' => 'ୟୁଗାରିଟିକ୍',
        'Vaii' => 'ୱାଇ',
        'Visp' => 'ଭିଜିବଲ୍ ସ୍ପିଚ୍',
        'Xpeo' => 'ପୁରୁଣା ଫରାସୀ',
        'Xsux' => 'ସୁମେରୋ-ଆକ୍କାଡିଆନ୍ ସୁନିଫର୍ମ',
        'Yiii' => 'ୟୀ',
        'Zinh' => 'ବଂଶଗତ',
        'Zmth' => 'ଗାଣିତିକ ନୋଟେସନ୍',
        'Zsye' => 'ଇମୋଜି',
        'Zsym' => 'ସଙ୍କେତଗୁଡ଼ିକ',
        'Zxxx' => 'ଅଲିଖିତ',
        'Zyyy' => 'ସାଧାରଣ',
    ],
];
